@@ -1,5 +1,5 @@
 package Text::Password::CoreCrypt;
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 
 use 5.008001;
 use Moose;  # this module is NOT based on Moose but it need to succeed
@@ -38,7 +38,25 @@ B<DON'T USE> directly.
 
 =head3 new()
 
-no arguments are required
+No arguments are required. But you can set some parameters.
+
+=over
+
+=item default
+
+You can set default length with param 'default' like below
+
+ $pwd = Text::Pasword::AutoMiglation->new( default => 12 );
+
+=item readablity
+
+Or you can set default strength for password with param 'readablity'.
+
+It must be a Boolen, default is 1.
+
+If it was set as 0, you can generate more strong passwords with generate()
+ 
+=back
 
 =head2 Methods and Subroutines
 
